# `chromatic`

The `chromatic-lightcurves` package is designed to be a friendly python tool to standardize working with and visualizing spectroscopic light curves. Deeply inspired by the [`lightkurve`](https://docs.lightkurve.org/) package developed by the Kepler Science Office, we aim for this tool to create something similar but adding a dimension for wavelength.

This package defines a spectroscopic light curve object (a `Rainbow`) with easy access to wavelength, time, flux, and uncertainty attributes. It should also allow reading and writing these datasets from/to a variety of formats and provide useful visualizations or tools. Read on for quick introductions to how these little 🌈s work!
